%global openas2dir %{_sharedstatedir}/openas2
%global bundle 1

Name:		openas2
Version:	2.3.0
Release:	5%{?dist}
Summary:	Java-based implementation of the EDIINT AS2 standard.

Group:		Applications/Communications
License:	BSD-2-Clause
URL:		https://github.com/OpenAS2/OpenAs2App
Source0:	https://github.com/OpenAS2/OpenAs2App/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz

# Use hsqldb instead of h2 for embedded database, since h2 depends on packages
# with licenses Fedora can't use.
#
# Pre-created hsqldb database.  FIXME: this should be loaded from db_ddl.sql
Source1:	hsqldb.tar
# Code changes to use hsqldb
Patch0:		openas2-hsqldb.patch

# Fix unit test that fails when run west of GMT :-)
Patch1:		openas2-tests.patch
# org.osgi.framework.ServiceRegistration does take a template parameter 
Patch2:		openas2-osgi.patch
# Use OPENAS2_BASE since start script can't be in /var/lib
Patch3:		openas2-fedora.patch
# openas2.service modified for this package's file layout
Source2:	openas2.service

BuildRequires:	maven-local dom4j javamail bouncycastle glassfish-servlet-api
BuildRequires:	findbugs hamcrest mockito sonatype-oss-parent hsqldb-lib
BuildRequires:	bouncycastle-mail bouncycastle-pkix bouncycastle-pg
BuildRequires:  mvn(org.apache.maven.plugins:maven-antrun-plugin)
BuildRequires:  mvn(org.apache.maven.plugins:maven-dependency-plugin)
# adding to try to make unit tests work in mock
%if 0
BuildRequires:  mvn(org.codehaus.mojo:build-helper-maven-plugin)
BuildRequires:  mvn(org.apache.maven.plugins:maven-toolchains-plugin)
BuildRequires:  mvn(org.apache.maven:maven-toolchain)
BuildRequires:  mvn(org.apache.felix:org.osgi.foundation)
BuildRequires:  mvn(org.apache.felix:org.osgi.compendium)
BuildRequires:  mvn(org.osgi:osgi.core)
BuildRequires:  mvn(org.osgi:org.osgi.annotation)
BuildRequires:  mvn(org.osgi:org.osgi.compendium)
BuildRequires:  mvn(org.apache.commons:commons-dbcp)
BuildRequires:  mvn(org.apache.commons:commons-pool)
%endif
#
Requires:	java >= 1.6
BuildArch:	noarch
BuildRequires: systemd

%description
OpenAS2 is a java-based implementation of the EDIINT AS2 standard. It is
intended to be used as a server. It is extremely configurable and supports a
wide variety of signing and encryption algorithms.

Version 2.3.0 was released on 3rd May 2017.

IMPORTANT: Read the release notes for running OpenAS2 with Java 1.5 and Java 1.6

This base package contains libraries and documentation.

%package server
Summary:	Preconfigured server application
Group:		Applications/Communications
BuildArch:	noarch
Requires:	openas2 systemd
Requires(post): systemd
Requires(preun): systemd
Requires(postun): systemd
%if bundle
Provides:	mvn(org.hsqldb:hsqldb)
Provides:	mvn(org.bouncycastle:bcpg-jdk15on)
Provides:	mvn(org.bouncycastle:bcmail-jdk15on)
%endif

%description server
A mostly preconfigured openas2 server, using hsqldb by default for a
standalone package.  It can be changed to used postgresql instead.

%package remote
Summary:	Remote command line and servlet interface
Group:		Applications/Communications
Requires:	openas2
BuildArch:	noarch

%description remote
Remote command line and servlet interfaces to a running openas2 server.

%package src
Summary:	OpenAS2 Java source
Group:		Applications/Communications
BuildArch:	noarch

%description src
The Java source files for OpenAS2

%package javadoc
Summary:	OpenAS2 API documentation
Group:		Applications/Communications
BuildArch:	noarch

%description javadoc
API documentation for OpenAS2

%prep
%setup -qn OpenAs2App-%{version}
%patch0 -b .hsqldb
%patch1 -b .tests
%patch2 -b .osgi
%patch3 -b .fedora
%pom_xpath_inject "pom:properties" "
	<project.build.sourceEncoding>UTF-8</project.build.sourceEncoding>"
%pom_change_dep org.dom4j: dom4j:dom4j:1.6.1 Server
%pom_remove_dep com.h2database: Server
%pom_add_dep org.hsqldb:hsqldb:2.3.0 Server
%pom_set_parent org.openas2:OpenAS2:2.3.0 Remote
%pom_set_parent org.openas2:OpenAS2:2.3.0 Bundle
# initial hsqldb database
tar xvf %{SOURCE1}
# remove binaries that came with the "source"
find . -name "*.jar" | xargs rm 
# remove h2 preloaded databases
find . -name "openas2.mv.db" | xargs rm 

%build
%mvn_build -- -Dmaven.test.skip=true

%install
%mvn_install

# systemd service
mkdir -p %{buildroot}%{_unitdir}
install -pm644 %{SOURCE2} %{buildroot}%{_unitdir}

# server application runs from /var/lib/openas2
mkdir -p %{buildroot}%{openas2dir}/{logs,data,bin,db,config}
ln -sf %{_libexecdir}/openas2/start-openas2.sh %{buildroot}%{openas2dir}/bin

# put scripts in /usr/libexec/openas2
mkdir -p %{buildroot}%{_libexecdir}/openas2
install -pm755 Server/target/dist/bin/start-openas2.sh \
	%{buildroot}%{_libexecdir}/openas2

# symlink library jars to /usr/share/java
cp -pr Server/target/dist/lib %{buildroot}%{openas2dir}
%if !%{bundle}
xmvn-subst %{buildroot}%{openas2dir}/lib # replace system jars with symlinks
%endif
ln -sf %{_javadir}/openas2/openas2-server.jar \
	%{buildroot}%{openas2dir}/lib/openas2-server*

# sample configurations in /etc/openas2
mkdir -p %{buildroot}%{_sysconfdir}/openas2
cp -p Server/target/dist/config/*.* %{buildroot}%{_sysconfdir}/openas2
cd %{buildroot}%{_sysconfdir}/openas2
# config.xml.hsqldb is the backup from the hsqldb patch
mv config.xml.hsqldb config.xml.h2
# symlink sample configurations to run dir where config expects them
# QUESTION: should we modify the config to use absolute paths to
# our run dir instead?
for i in *.*; do
  ln -sf %{_sysconfdir}/openas2/"$i" %{buildroot}%{openas2dir}/config
done
cd -
# template hsqldb database 
cp -pr Server/target/dist/config/DB %{buildroot}%{openas2dir}/config

# create /var/run/openas2
mkdir -p %{buildroot}/var/run/openas2
mkdir -p %{buildroot}%{_sysconfdir}/tmpfiles.d
cat >%{buildroot}%{_sysconfdir}/tmpfiles.d/openas2.conf <<EOF
D /var/run/openas2 0755 openas2 openas2 -
EOF

%files -f .mfiles
%license LICENSE.txt
%doc changes.txt README.md RELEASE-NOTES.txt docs/*
%dir %{_javadir}/%{name}

%pre
getent group openas2 > /dev/null || groupadd -r openas2
getent passwd openas2 > /dev/null || /usr/sbin/useradd -g openas2 \
        -c "Java EDIINT AS2 Server" \
        -r -d %{openas2dir} -s /sbin/nologin openas2
exit 0

%files javadoc 
%license LICENSE.txt
%{_javadocdir}/*

%files server
%{_libexecdir}/openas2
%{_unitdir}/*
%{_sysconfdir}/tmpfiles.d/*
%attr(0755,root,root) %dir %{openas2dir}
%attr(0755,root,root) %{openas2dir}/bin
%attr(0755,root,root) %{openas2dir}/lib
%attr(0755,root,root) %dir %{_sysconfdir}/openas2
%attr(0755,root,root) %config %{_sysconfdir}/openas2/*
%{openas2dir}/config
%attr(0755,openas2,openas2) %dir %{openas2dir}/db
%attr(0755,openas2,openas2) %{openas2dir}/data
%attr(0755,openas2,openas2) %{openas2dir}/logs
%attr(0755,openas2,openas2) %dir /var/run/openas2

%post server
%systemd_post openas2.service

%postun server
%systemd_postun_with_restart openas2.service

%preun server
%systemd_preun openas2.service

%if 0
%files remote
%license Remote/docs/license.txt
%doc Remote/docs/Readme.txt
%{_libexecdir}/openas2-remote

%files src
%{_libexecdir}/openas2/src
%{_libexecdir}/openas2-remote/src
%endif

%changelog

* Mon Aug  7 2017 Stuart D. Gathman <stuart@gathman.org> 2.3.0-5
- Add bundle option to allow installing binary rpms on EL7
- Move openas2-server config to /etc/openas2

* Wed Aug  2 2017 Stuart D. Gathman <stuart@gathman.org> 2.3.0-4
- hsqldb can't handle upper case dbdir
- hsqldb puts lock file in working dir

* Wed Aug  2 2017 Stuart D. Gathman <stuart@gathman.org> 2.3.0-3
- /var/lib/openas2/bin cannot be symlink

* Tue Aug  1 2017 Stuart D. Gathman <stuart@gathman.org> 2.3.0-2
- start script cannot be in /var/lib

* Tue Aug  1 2017 Stuart D. Gathman <stuart@gathman.org> 2.3.0-1
- Initial rpm
